@@ -3,7 +3,8 @@ from .itertoolz import (groupby, countby, frequencies, reduceby,
                         get, merge_sorted, concat, concatv, mapcat,
                         isdistinct, interleave, unique, intersection,
                         isiterable, remove, iterate, accumulate,
-                        partitionby, sliding_window, count)
+                        partitionby, partition, partition_all,
+                        sliding_window, count)
 
 from .functoolz import (memoize, curry, compose, thread_first,
                         thread_last, identity, pipe)
@@ -12,6 +13,8 @@ from .dicttoolz import merge, merge_with, keymap, valmap, assoc, update_in
 
 from .compatibility import map, filter
 
+from . import sandbox
+
 from functools import partial, reduce
 
 sorted = sorted
@@ -19,4 +22,4 @@ sorted = sorted
 # Aliases
 comp = compose
 
-__version__ = '0.4.0'
+__version__ = '0.4.1'
