@@ -27,12 +27,12 @@ def partitionby(f, seq):
     and that and subsequent items are collected into that list.
 
     >>> is_space = lambda c: c == " "
-    >>> list(partitionby(is_space, "I have spaces"))
-    [['I'], [' '], ['h', 'a', 'v', 'e'], [' '], ['s', 'p', 'a', 'c', 'e', 's']]
+    >>> list(partitionby(is_space, "I have space"))
+    [('I',), (' ',), ('h', 'a', 'v', 'e'), (' ',), ('s', 'p', 'a', 'c', 'e')]
 
     >>> is_large = lambda x: x > 10
     >>> list(partitionby(is_large, [1, 2, 1, 99, 88, 33, 99, -1, 5]))
-    [[1, 2, 1], [99, 88, 33, 99], [-1, 5]]
+    [(1, 2, 1), (99, 88, 33, 99), (-1, 5)]
 
     See also:
         partition
@@ -41,4 +41,4 @@ def partitionby(f, seq):
     """
     # Note: applying `list` seems to be required both Python 2 and 3
     # compatible (Python 3 works without it).
-    return (list(v) for k, v in itertools.groupby(seq, key=f))
+    return (tuple(v) for k, v in itertools.groupby(seq, key=f))
